package com.cash_gl.cash_gl_plugin;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.Context;
import android.content.Intent;
import android.graphics.Color;
import android.util.Log;

import androidx.annotation.NonNull;

import com.mpurse.pay.View.Entity.PayEntity;
import com.mpurse.pay.View.util.MYPauseConstants;
import com.mpurse.pay.mPausePayPresenter;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/**
 * CashGlPlugin
 */
public class CashGlPlugin implements FlutterPlugin, PluginRegistry.ActivityResultListener, MethodCallHandler, ActivityAware {

    private Context context;

    private MethodChannel channel;

    /**
     * Plugin registration.
     */
    public static void registerWith(PluginRegistry.Registrar registrar) {
        Log.i("CashGlPlugin", "====registerWith");
        final CashGlPlugin instance = new CashGlPlugin();
        instance.onAttachedToEngine(registrar.activity(), registrar.messenger());
    }

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        Log.i("CashGlPlugin", "====onAttachedToEngine");
        onAttachedToEngine(flutterPluginBinding.getApplicationContext(), flutterPluginBinding.getBinaryMessenger());
    }

    private void onAttachedToEngine(Context context, BinaryMessenger messenger) {
        this.context = context;
        this.channel = new MethodChannel(messenger, "com.cash_gl.cash_gl_plugin");
        this.channel.setMethodCallHandler(this);
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        if ("payWithMpurse".equals(call.method)) {
            Log.i("CashGlPlugin", "onMethodCall.payWithMpurse");
            Log.i("CashGlPlugin", context + "");
            payWithMpurse((String) call.argument("amount"), (String) call.argument("txnId"),
                    (String) call.argument("mpQueryId"), (String) call.argument("partnerId"),
                    (String) call.argument("createTime"), (String) call.argument("payerVa"),
                    (int) call.argument("code"));
        } else {
            result.notImplemented();
        }
    }

    @Override
    public boolean onActivityResult(int requestCode, int resultCode, Intent data) {
        Log.i("CashGlPlugin", "onActivityResult:" + resultCode);
        switch (resultCode) {
            case MYPauseConstants.TYPE:
                switch (data.getIntExtra("BACK", 0)) {
                    case MYPauseConstants.RESULT_BACK_CODE://退出支付SDK
                        Log.i("CashGlPlugin", "RESULT_BACK_CODE");
                        break;
                }
        }
        return true;
    }

    private void payWithMpurse(String amount, String txnId, String mpQueryId,
                               String partnerId, String createTime, String payerVa,
                               int code) {
        Log.i("CashGlPlugin", "before payWithMpurse");
        Log.i("CashGlPlugin", amount);
        Log.i("CashGlPlugin", txnId);
        Log.i("CashGlPlugin", mpQueryId);
        Log.i("CashGlPlugin", partnerId);
        Log.i("CashGlPlugin", createTime);
        Log.i("CashGlPlugin", payerVa);
        Log.i("CashGlPlugin", code + "");

        mPausePayPresenter mPayPresenter = new mPausePayPresenter();
        // 设置标题背景色
        mPayPresenter.SetTitleColor(Color.parseColor("#FF3333"));
        // 设置按钮颜色及Tab颜色
        mPayPresenter.SetButtonColor(Color.parseColor("#FF3333"));

        PayEntity payEntity = new PayEntity();
        payEntity.setAmount(amount);
        payEntity.setTxnId(txnId);
        payEntity.setMpQueryId(mpQueryId);
        payEntity.setPartnerId(partnerId);
        payEntity.setCreateTime(createTime);
        payEntity.setPayerVA(payerVa);
        mPayPresenter.getNetBank((Activity) context, payEntity, code);
        Log.i("CashGlPlugin", "after payWithMpurse");
    }

    private void showAlertDialog(String content) {
        Log.i("CashGlPlugin", "before");
        AlertDialog.Builder builder = new AlertDialog.Builder(context);
        Log.i("CashGlPlugin", "after");
        builder.setPositiveButton("确定", null);
        builder.setTitle(content);
        builder.show();
        Log.i("CashGlPlugin", "after2");
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        this.context = null;
        this.channel.setMethodCallHandler(null);
        this.channel = null;
    }

    @Override
    public void onAttachedToActivity(ActivityPluginBinding binding) {
        Log.i("CashGlPlugin", "====onAttachedToActivity");
        this.context = binding.getActivity();
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {

    }

    @Override
    public void onReattachedToActivityForConfigChanges(ActivityPluginBinding binding) {

    }

    @Override
    public void onDetachedFromActivity() {

    }
}
